@@ -64,6 +64,7 @@ class PeopleMeta(sc.prettyobj):
             'tested',
             'diagnosed',
             'recovered',
+            'known_dead',
             'dead',
             'known_contact',
             'quarantined',
@@ -146,6 +147,7 @@ result_stocks = {
     'recovered':   'Number recovered',
     'dead':        'Number dead',
     'diagnosed':   'Number of confirmed cases',
+    'known_dead':  'Number of confirmed deaths',
     'quarantined': 'Number in quarantine',
     'vaccinated':  'Number of people vaccinated',
 }
@@ -167,6 +169,7 @@ result_flows = {
     'deaths':       'deaths',
     'tests':        'tests',
     'diagnoses':    'diagnoses',
+    'known_deaths': 'known deaths',
     'quarantined':  'quarantined people',
     'vaccinations': 'vaccinations',
     'vaccinated':   'vaccinated people'
@@ -260,6 +263,8 @@ def get_default_colors():
     c.critical              = '#b86113'
     c.deaths                = '#000000'
     c.dead                  = c.deaths
+    c.known_dead            = c.deaths
+    c.known_deaths          = c.deaths
     c.default               = '#000000'
     c.pop_nabs              = '#32733d'
     c.pop_protection        = '#9e1149'
@@ -273,6 +278,7 @@ overview_plots = [
     'cum_severe',
     'cum_critical',
     'cum_deaths',
+    'cum_known_deaths',
     'cum_diagnoses',
     'new_infections',
     'new_severe',
@@ -317,7 +323,7 @@ def get_default_plots(which='default', kind='sim', sim=None):
     # Default plots -- different for sims and scenarios
     if which in [None, 'default']:
 
-        if kind == 'sim':
+        if 'sim' in kind:
             plots = sc.odict({
                     'Total counts': [
                         'cum_infections',
@@ -332,10 +338,11 @@ def get_default_plots(which='default', kind='sim', sim=None):
                         'cum_severe',
                         'cum_critical',
                         'cum_deaths',
+                        'cum_known_deaths',
                     ],
             })
 
-        elif kind == 'scens': # pragma: no cover
+        elif 'scen' in kind: # pragma: no cover
             plots = sc.odict({
                 'Cumulative infections': [
                     'cum_infections',
@@ -345,9 +352,14 @@ def get_default_plots(which='default', kind='sim', sim=None):
                 ],
                 'Cumulative deaths': [
                     'cum_deaths',
+                    'cum_known_deaths',
                 ],
             })
 
+        else:
+            errormsg = f'Expecting "sim" or "scens", not "{kind}"'
+            raise ValueError(errormsg)
+
     # Show an overview
     elif which == 'overview': # pragma: no cover
         plots = sc.dcp(overview_plots)
