@@ -44,12 +44,7 @@ class People(cvb.BasePeople):
     def __init__(self, pars, strict=True, **kwargs):
 
         # Handle pars and population size
-        if sc.isnumber(pars): # Interpret as a population size
-            pars = {'pop_size':pars} # Ensure it's a dictionary
-        self.pars = pars # Equivalent to self.set_pars(pars)
-        self.pars['pop_size'] = int(pars['pop_size'])
-        self.pars.setdefault('n_strains', 1)
-        self.pars.setdefault('location', None)
+        self.set_pars(pars)
         self.version = cvv.__version__ # Store version info
 
         # Other initialization
@@ -92,7 +87,8 @@ class People(cvb.BasePeople):
 
         # Store the dtypes used in a flat dict
         self._dtypes = {key:self[key].dtype for key in self.keys()} # Assign all to float by default
-        self._lock = strict # If strict is true, stop further keys from being set (does not affect attributes)
+        if strict:
+            self.lock() # If strict is true, stop further keys from being set (does not affect attributes)
 
         # Store flows to be computed during simulation
         self.init_flows()
@@ -172,16 +168,18 @@ class People(cvb.BasePeople):
 
         # Initialize
         self.t = t
-        self.is_exp = self.true('exposed') # For storing the interim values since used in every subsequent calculation
+        self.is_exp     = self.true('exposed') # For storing the interim values since used in every subsequent calculation
 
         # Perform updates
         self.init_flows()
-        self.flows['new_infectious']  += self.check_infectious() # For people who are exposed and not infectious, check if they begin being infectious
-        self.flows['new_symptomatic'] += self.check_symptomatic()
-        self.flows['new_severe']      += self.check_severe()
-        self.flows['new_critical']    += self.check_critical()
-        self.flows['new_deaths']      += self.check_death()
-        self.flows['new_recoveries']  += self.check_recovery() # TODO: check logic here
+        self.flows['new_infectious']    += self.check_infectious() # For people who are exposed and not infectious, check if they begin being infectious
+        self.flows['new_symptomatic']   += self.check_symptomatic()
+        self.flows['new_severe']        += self.check_severe()
+        self.flows['new_critical']      += self.check_critical()
+        self.flows['new_recoveries']    += self.check_recovery()
+        new_deaths, new_known_deaths    = self.check_death()
+        self.flows['new_deaths']        += new_deaths
+        self.flows['new_known_deaths']  += new_known_deaths
 
         return
 
@@ -279,6 +277,7 @@ class People(cvb.BasePeople):
         self.exposed_by_strain[:, inds] = False
         self.infectious_by_strain[:, inds] = False
 
+
         # Handle immunity aspects
         if self.pars['use_waning']:
 
@@ -288,31 +287,35 @@ class People(cvb.BasePeople):
 
             # Reset additional states
             self.susceptible[inds] = True
+            self.diagnosed[inds]   = False # Reset their diagnosis state because they might be reinfected
             self.prior_symptoms[inds]        = self.pars['rel_imm_symp']['asymp']
             self.prior_symptoms[mild_inds]   = self.pars['rel_imm_symp']['mild']
             self.prior_symptoms[severe_inds] = self.pars['rel_imm_symp']['severe']
             if len(inds):
                 cvi.init_nab(self, inds, prior_inf=True)
+
         return len(inds)
 
 
     def check_death(self):
         ''' Check whether or not this person died on this timestep  '''
         inds = self.check_inds(self.dead, self.date_dead, filter_inds=self.is_exp)
-        self.susceptible[inds]   = False
-        self.exposed[inds]       = False
-        self.infectious[inds]    = False
-        self.symptomatic[inds]   = False
-        self.severe[inds]        = False
-        self.critical[inds]      = False
-        self.known_contact[inds] = False
-        self.quarantined[inds]   = False
-        self.recovered[inds]     = False
-        self.dead[inds]          = True
+        self.dead[inds]             = True
+        diag_inds = inds[self.diagnosed[inds]] # Check whether the person was diagnosed before dying
+        self.known_dead[diag_inds]  = True
+        self.susceptible[inds]      = False
+        self.exposed[inds]          = False
+        self.infectious[inds]       = False
+        self.symptomatic[inds]      = False
+        self.severe[inds]           = False
+        self.critical[inds]         = False
+        self.known_contact[inds]    = False
+        self.quarantined[inds]      = False
+        self.recovered[inds]        = False
         self.infectious_strain[inds] = np.nan
         self.exposed_strain[inds]    = np.nan
         self.recovered_strain[inds]  = np.nan
-        return len(inds)
+        return len(inds), len(diag_inds)
 
 
     def check_diagnosed(self):
